﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PropertyModifiers
{
    public class Actor : BaseObject
    {
        private Dictionary<ArmorSlots, Armor> armorItems;
        private Dictionary<ActorProperties, IProperty<float>> properties;
        Array armorSlots = Enum.GetValues(typeof(ArmorSlots));
        private string name = string.Empty;



        public string Name
        {
            get { return name; }
            set { name = value; }
        }

        public Actor(IGameService service)
            : base(service)
        {
            // create properties  
            this.properties = new Dictionary<ActorProperties, IProperty<float>>();
            this.weight.BaseValue = 175;

            this.properties[ActorProperties.Agility] = new FloatProperty(1);
            this.properties[ActorProperties.Armor] = new FloatProperty(1);
            this.properties[ActorProperties.Dodge] = new FloatProperty(1);
            this.properties[ActorProperties.Intellect] = new FloatProperty(10);
            this.properties[ActorProperties.Parry] = new FloatProperty(1);
            this.properties[ActorProperties.Speed] = new FloatProperty(1);
            this.properties[ActorProperties.Spirit] = new FloatProperty(1);
            this.properties[ActorProperties.Stamina] = new FloatProperty(100);
            this.properties[ActorProperties.Strength] = new FloatProperty(5);
            this.properties[ActorProperties.Weight] = this.weight;

            this.armorItems = new Dictionary<ArmorSlots, Armor>();
            foreach (ArmorSlots slot in this.armorSlots)
            {
                this.armorItems.Add(slot, null);
            }
        }

        public IProperty<float> GetProperty(ActorProperties index)
        {
            return this.properties[index];
        }

        public void SetProperty(ActorProperties index, IProperty<float> value)
        {
            this.properties[index] = value;
        }

        public int EquipArmorItem(ArmorSlots index, Armor item)
        {
            if (item != null && index != item.Slot) return -1;
            if (this.armorItems[index] != null) this.UnEquipArmorItem(index);
            this.armorItems[index] = item;
            if (item != null) item.Equip(this);
            return 0;
        }

        public int EquipArmorItem(Armor item)
        {
            if (item == null) return -1;
            if (this.armorItems[item.Slot] != null) this.UnEquipArmorItem(item.Slot);
            this.armorItems[item.Slot] = item;
            item.Equip(this);
            return 0;
        }

        public void UnEquipArmorItem(ArmorSlots index)
        {
            Armor item = this.armorItems[index];
            if(item ==null) return;
            item.UnEquip(this);
            this.armorItems[index] = null;
        }

        public Armor GetArmorItem(ArmorSlots index)
        {
            return this.armorItems[index];
        }

        public void Update(TimeSpan gameTime)
        {
            
        }
    }
}
