﻿using System;
using System.Collections.Generic;
 
namespace PropertyModifiers
{
    abstract public class Armor : Item
    {
        protected Dictionary<ActorProperties, IPropertyModifier<float>> actorModifiers;
        readonly Array propNames = Enum.GetValues(typeof(ActorProperties));
        internal protected Actor actor;


        public Armor(IGameService service)
            : base(service)
        {
            this.actorModifiers = new Dictionary<ActorProperties, IPropertyModifier<float>>();
            foreach (ActorProperties prop in this.propNames)
            {
                this.actorModifiers.Add(prop, null);
            }
        }

        public virtual void Equip(Actor act)
        {
            if (this.actor != null) return;
            this.actor = act;
            foreach (ActorProperties prop in this.propNames)
            {
                IProperty<float> value = act.GetProperty(prop);
                IPropertyModifier<float> mod = this.actorModifiers[prop];
                if (mod != null && value != null) value.Modifiers.Add(mod);
            }
        }

        public virtual void UnEquip(Actor act)
        {
            if (this.actor == act)
            {
                foreach (ActorProperties prop in this.propNames)
                {
                    IProperty<float> value = act.GetProperty(prop);
                    if (value != null)
                    {
                        IPropertyModifier<float> modifier = this.actorModifiers[prop];
                        if (modifier != null) value.Modifiers.Remove(modifier);
                    }
                }
                if (this.useability != null) this.useability.Stop();
                this.actor = null;
            }
        }

        abstract public ArmorSlots Slot { get; }
    }
}
