﻿using System;
 using System.Windows.Forms;

namespace PropertyModifiers
{
    public partial class Form1 : Form
    {
        private Actor actor;
        private IGameService gameService;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.gameService = new GameService();
            this.actor = new Actor(this.gameService);

            this.lvItems.Items.Add(new CustomListViewItem(new SimpleHelmut(this.gameService), "Head"));
            this.lvItems.Items.Add(new CustomListViewItem(new SteelChest(this.gameService), "Chest"));
            this.lvItems.Items.Add(new CustomListViewItem(new LeatherGloves(this.gameService), "Hands"));
            this.lvItems.Items.Add(new CustomListViewItem(new SpiritNecklace(this.gameService), "Neck"));
            this.lvItems.Items.Add(new CustomListViewItem(new SwiftBoots(this.gameService), "Feet"));

            this.pbBack.Tag = ArmorSlots.Back;
            this.pbChest.Tag = ArmorSlots.Chest;
            this.pbFeet.Tag = ArmorSlots.Feet;
            this.pbHands.Tag = ArmorSlots.Hands;
            this.pbHead.Tag = ArmorSlots.Head;
            this.pbLegs.Tag = ArmorSlots.Legs;
            this.pbNeck.Tag = ArmorSlots.Neck;
            this.pbSholder.Tag = ArmorSlots.Sholders;
            this.pbWaist.Tag = ArmorSlots.Waist;
            this.pbWrist.Tag = ArmorSlots.Wrist;

            this.updateTimer.Start();
        }

        private void EquipItem(object sender, MouseEventArgs e)
        {
            var pb = (PictureBox)sender;
            if (e.Button == MouseButtons.Right)
            {
                pb.Image = null;
                this.actor.UnEquipArmorItem((ArmorSlots)pb.Tag);
            }
            else if (e.Button == MouseButtons.Left)
            {
                Armor item = this.actor.GetArmorItem((ArmorSlots)pb.Tag);
                item.Use();
            }
        }

        public void UpdateLables()
        {
            this.lblAgility.Text = this.actor.GetProperty(ActorProperties.Agility).Value.ToString();
            this.lblArmor.Text = this.actor.GetProperty(ActorProperties.Armor).Value.ToString();
            this.lblDodge.Text = this.actor.GetProperty(ActorProperties.Dodge).Value.ToString();
            this.lblIntellect.Text = this.actor.GetProperty(ActorProperties.Intellect).Value.ToString();
            this.lblParry.Text = this.actor.GetProperty(ActorProperties.Parry).Value.ToString();
            this.lblSpirit.Text = this.actor.GetProperty(ActorProperties.Spirit).Value.ToString();
            this.lblStamina.Text = this.actor.GetProperty(ActorProperties.Stamina).Value.ToString();
            this.lblStrength.Text = this.actor.GetProperty(ActorProperties.Strength).Value.ToString();
            this.lblWeight.Text = this.actor.Weight.Value.ToString();
            this.lblSpeed.Text = this.actor.GetProperty(ActorProperties.Speed).Value.ToString();
        }

        private void btnEquip_Click(object sender, EventArgs e)
        {
            // equip item from list
            foreach (CustomListViewItem item in this.lvItems.SelectedItems)
            {
                this.actor.EquipArmorItem(item.ArmorItem);
                PictureBox box = GetPictureBox(item);
                box.Image = this.imlIcons.Images[item.ImageKey];
            }
        }

        private PictureBox GetPictureBox(CustomListViewItem item)
        {
            PictureBox box = null;
            switch (item.ArmorItem.Slot)
            {
                case ArmorSlots.Head:
                    box = pbHead;
                    break;
                case ArmorSlots.Neck:
                    box = pbNeck;
                    break;
                case ArmorSlots.Chest:
                    box = pbChest;
                    break;
                case ArmorSlots.Legs:
                    box = pbLegs;
                    break;
                case ArmorSlots.Waist:
                    box = pbWaist;
                    break;
                case ArmorSlots.Hands:
                    box = pbHands;
                    break;
                case ArmorSlots.Feet:
                    box = pbFeet;
                    break;
                case ArmorSlots.Sholders:
                    box = pbSholder;
                    break;
                case ArmorSlots.Back:
                    box = pbBack;
                    break;
                case ArmorSlots.Wrist:
                    box = pbWrist;
                    break;
                default:
                    // do nothing
                    break;
            }
            return box;
        }

        private void ShowToolTip(Control ctrl, ArmorSlots slot)
        {
            Armor item = this.actor.GetArmorItem(slot);
            if (item == null) return;
            ttInfo.ToolTipTitle = item.Name;
            ttInfo.ToolTipIcon = ToolTipIcon.Info;
            ttInfo.SetToolTip(ctrl, item.Description);
        }

        private void ShowItemToolTip(object sender, EventArgs e)
        {
            var pb = (PictureBox)sender;
            ShowToolTip(pb, (ArmorSlots)pb.Tag);
        }

        private void updateTimer_Tick(object sender, EventArgs e)
        {
            this.gameService.Update(TimeSpan.FromTicks(DateTime.Now.Ticks));
            this.actor.Update(TimeSpan.FromTicks(DateTime.Now.Ticks));
            this.UpdateLables();
        }
    }
}
