using System;

namespace PropertyModifiers
{
    public class LeatherGloves : Armor
    {
        private IPropertyModifier<float> strengthModifier;


        public override ArmorSlots Slot
        {
            get { return ArmorSlots.Hands; }
        }

        void useableRef_StartUsage(object sender, UsageEventArgs e)
        {
            IProperty<float> strengthProp = this.actor.GetProperty(ActorProperties.Strength);
            if (strengthProp != null)
            {
                strengthProp.Modifiers.Add(this.strengthModifier);
                e.ReturnValue = true;
                return;
            }

            e.ReturnValue = false;
        }

        void useableRef_StopUsage(object sender, UsageEventArgs e)
        {
            IProperty<float> strengthProp = this.actor.GetProperty(ActorProperties.Strength);
            if (strengthProp != null)     strengthProp.Modifiers.Remove(this.strengthModifier);
        }

        public LeatherGloves(IGameService service)
            : base(service)
        {
            this.name = "Leather Gloves";
            this.description = "Equip: Increases armor by 5 and agility by 10.\nUse: Increases strength by 5 for 5 seconds.";
            this.weight.BaseValue = 4;
            this.useability = new UsableObject(service);
            this.useability.SetDuration(TimeSpan.FromSeconds(5));
            this.useability.StartUsage += this.useableRef_StartUsage;
            this.useability.StopUsage += this.useableRef_StopUsage;
            this.actorModifiers[ActorProperties.Weight] = new BasicPropertyModifier<float>(this.weight.Value);
            this.actorModifiers[ActorProperties.Armor] = new BasicPropertyModifier<float>(5);
            this.actorModifiers[ActorProperties.Agility] = new BasicPropertyModifier<float>(10);
            this.strengthModifier = new BasicPropertyModifier<float>(5);
        }
    }
}