using System;

namespace PropertyModifiers
{
    public class SpiritNecklace : Armor
    {
        private IPropertyModifier<float> spiritModifier;
        private IPropertyModifier<float> staminaModifier;


        public override ArmorSlots Slot
        {
            get { return ArmorSlots.Neck; }
        }

          public SpiritNecklace(IGameService service)
            : base(service)
        {
            this.name = "Sprit Necklace";
            this.description = "Equip: Increases spirit by 5.\nUse: Converts 1% stamina into spirit for 5 seconds.";
            this.weight.BaseValue = 1;
            this.useability = new UsableObject(service);
            this.useability.SetDuration(TimeSpan.FromSeconds(5));
            this.useability.StartUsage += this.useableRef_StartUsage;
            this.useability.StopUsage += this.useableRef_StopUsage;
            this.actorModifiers[ActorProperties.Weight] = new BasicPropertyModifier<float>(this.weight.Value);
            this.actorModifiers[ActorProperties.Spirit] = new BasicPropertyModifier<float>(5);
            this.spiritModifier = new BasicPropertyModifier<float>(5);
            this.staminaModifier = new BasicPropertyModifier<float>(5);
        }

        void useableRef_StopUsage(object sender, UsageEventArgs e)
        {
            this.actor.GetProperty(ActorProperties.Spirit).Modifiers.Remove(this.spiritModifier);
            this.actor.GetProperty(ActorProperties.Stamina).Modifiers.Remove(this.staminaModifier);
        }

        void useableRef_StartUsage(object sender, UsageEventArgs e)
        {
            IProperty<float> staminaProp = this.actor.GetProperty(ActorProperties.Stamina);
            if (staminaProp != null)
            {
                float storedValue = staminaProp.Value * 0.01f;
                this.spiritModifier.Value = storedValue;
                this.staminaModifier.Value = -storedValue;
                this.actor.GetProperty(ActorProperties.Spirit).Modifiers.Add(this.spiritModifier);
                staminaProp.Modifiers.Add(this.staminaModifier);
                e.ReturnValue = true;
                return;
            }

            e.ReturnValue= false;
        }
    }
}