using System;

namespace PropertyModifiers
{
    public class SwiftBoots : Armor
    {
        private IPropertyModifier<float> speedModifier;


        public override ArmorSlots Slot
        {
            get { return ArmorSlots.Feet; }
        }

        void useableRef_StartUsage(object sender, UsageEventArgs e)
        {
            IProperty<float> staminaProp = this.actor.GetProperty(ActorProperties.Stamina);
            if (staminaProp != null)
            {
                this.speedModifier.Value = 10.0f;
                this.actor.GetProperty(ActorProperties.Speed).Modifiers.Add(this.speedModifier);
                e.ReturnValue = true;
                return;
            }

            e.ReturnValue = false;
        }

        void useableRef_StopUsage(object sender, UsageEventArgs e)
        {
            this.actor.GetProperty(ActorProperties.Speed).Modifiers.Remove(this.speedModifier);
        }

        public SwiftBoots(IGameService service)
            : base(service)
        {
            this.name = "Swift Boots";
            this.description = "Equip: Increases Speed by 5.\nUse: Increases speed by 10 for 12 seconds.";
            this.weight.BaseValue = 2;
            this.useability = new UsableObject(service);
            this.useability.SetDuration(TimeSpan.FromSeconds(12));
            this.useability.StartUsage += this.useableRef_StartUsage;
            this.useability.StopUsage += this.useableRef_StopUsage;
            this.actorModifiers[ActorProperties.Speed] = new BasicPropertyModifier<float>(5);
            this.speedModifier = new BasicPropertyModifier<float>(10);
            this.useability.SetCharges(3);
            this.useability.SetCooldown(TimeSpan.FromMinutes(1));
        }
    }
}